# -*-Perl-*-

# Author         : Shahriar Mokhtarzad
# Maintainer     : Shahriar Mokhtarzad
# e-mail         : contact_smt@pacbell.net
# Created        : Tue Mar 30 2004
# File name      : Send.pm
#
#=============================================================================
# Copyright (C) Shahriar Mokhtarzad. All Rights Reserved.
# This program is free software; you can redistribute it and/or  modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#=============================================================================

use             5.6.0;
package		Bugzilla::Send;
require		Exporter;
@ISA          = qw( Exporter );
use             Carp;

$VERSION = "0.01" ;

use             strict;

sub Mail {
  my( $to,
      $msg,
      $source,  #location in the code where call was made (for debugging)
      $trim,  # bugzilla specific flag
      $sendmailparam  # bugzilla specific flag
    ) = @_;

  my $from = '<email address for From:...>';
  my $server_type = '<server type>';  # SMTP, SMTP_AUTH, SENDMAIL
  my $athu_protocol = '<authentication method>';  # LOGIN, DIGEST-MD5, CRAM-MD5, PLAIN.
  my $server_name = '<mail server name (mailhost)';
  my $account_name = '<account name>';
  my $account_passwrod = '<password for the account>';
  my $debug_file = '<full path to a file for keeping copy of the entire mail taction>';
  my $debug = undef;  # set to "1" for debug mode (both send mail capture
                      # the entire transaction

  if( ! defined $to ) {
    $msg =~ /\bTo\:\s+(.+)\s*\b/o;
    $to = $1;
  }
  # Use die on error, so that the mail will be in the 'unsent mails' and
  # can be sent from the sanity check page.

  if( defined $debug ) {
    if( -f $debug_file ) {
      open( DEBUGFILE, ">>$debug_file" ) || croak"$! $debug_file";
    }
    else {
      open( DEBUGFILE, ">$debug_file" ) || croak"$! $debug_file";
    }
    # send the STDOUT and the STDERR to the debug file
    $| = 1;
    open(STDERR, ">&DEBUGFILE");
    #open(STDOUT, ">&DEBUGFILE");

    my $date = `date`;  # NOW timestamp
    chomp( $date );
    print DEBUGFILE "\nMessage being sent :: source = $source \n($date)\n";
     if( defined $to ) {
       print DEBUGFILE "to = $to\n";
     }
    else {
      print DEBUGFILE "to = undefined\n";
    }
    print DEBUGFILE "="x60, "\n",  $msg, "="x60, "\n";
    close( DEBUGFILE );
  }

  #SMTP protocol WITHOUT authentication usually for inhouse mail servers
  if( $server_type eq 'SMTP' ) {
    use Net::SMTP;
    my $smtp = Net::SMTP->new( $server_name,
                               Debug => $debug
                             ) ||
                               croak 'Cannot connect to server \'$server_name\'';
    $smtp->mail($from);
    $smtp->to($to);
    $smtp->data();
    $smtp->datasend($msg);
    $smtp->dataend();
    $smtp->quit;
  }
  #SMTP protocol WITH  Authenticaion usually for ISP mail servers
  elsif( $server_type eq "SMTP_AUTH" ) {
    use Net::SMTP_auth;

    my $smtp = Net::SMTP_auth->new( $server_name,
				    Debug => $debug ) ||
       croak 'Cannot connect to server \'$server_name\'';

    $smtp->auth( $athu_protocol, $account_name, $account_passwrod );
    $smtp->mail( $from );
    $smtp->to( $to );
    $smtp->data();
    $smtp->datasend( $msg );
    $smtp->dataend();
    $smtp->quit;

  }

  # the Unix SENDMAIL
  elsif( $server_type eq "SENDMAIL" ) {
    open(SENDMAIL, "|/usr/lib/sendmail $sendmailparam -t -i") ||
      die "Can't open sendmail";

    if( defined $trim ) {
      print SENDMAIL trim($msg) . "\n";
    }
    else { print SENDMAIL $msg; }
    close SENDMAIL;
  }
}

1;


__DATA__

=head1 NAME

Bugzilla::Send::Mail - is a module to extend the mail on bugzilla-2.17.7 (possibly
other version that are based on 2.17.7) to use SMTP, SMTP_auth and the sntandard
SENDMAIL. This will make WIN32 installtions a little easier. I have tested the
mail setup on WIN32 but have not tested it on Unix. The send mail shoud work.
you might have to tweak the "undef" to "" if you have problems with it.


=head1 Installing the new mail

=head2 Install the following perl modules

The following modules can be installed from CPAN or ASPN

  Net-SMTP_auth
  Net-SMTP

ASPN example

  ppm3 install Net-SMTP_auth
  ppm3 install Net-SMTP

=head2 Installing the bugzilla files

These two files are new:

  Send.pm   <-- new mail module
  check_mail.pl  <- a simple script to test your configuration by sendin a test
                    email

The following files are modified to direct the mail requests to the new B<Send.pm>
module.

  BugMail.pm
  CGI.pm
  move.pl
  globals.pl
  whineatnews.pl
  CGI.pl
  Token.pm
  importxml.pl

Copy the B<Send.pm> and B<BugMail.pm> to the I<"bugzilla installation directory"/Bugzilla>.

Copy check_mail.pl, CGI.pm, move.pl, globals.pl, whineatnews.pl, CGI.pl, Token.pm, importxml.pl
to the I<"bugzilla installation directory"> directory.


=head1 Configuring the new mail

I have not had time to workout the configuration scheme. Since I am pressed for time,
I decided to edit the B<Send.pm> for configuring the mail.

=over 4

=item $from = '<email address for From:...>'

This is the email adress the appears in the "From:.." in the e-mail. Bugzilla, will
modify this when necessary.

=item  $server_type = '<server type>'

Server tyes are B<SMTP, SMTP_AUTH, SENDMAIL>. usually if you your mail server is in
an ISP (usually need authentication) set to B<SMTP_AUTH>. If you are using a
in-house SMTP server that does B<not> require authentication then use SMTP.
If you want to use the default sendmail then set to B<SENDMAIL>.

=item $athu_protocol = '<authentication protocol>'

The protocols names are B<LOGIN, DIGEST-MD5, CRAM-MD5, PLAIN>. Most ISPs use PLAIN
or LOGIN. If you do not need authentication (if you are using SMTP or SENDMAIL)
the set this to B<undef> (the value is irrelevant).

=item $server_name = '<mail server name (mailhost)'

This is the name of the SMT server or(mailhost).

=item $account_name = '<account name>'

This is the name of the email SMTP account. If using the B<SENDMAIL> then set to
B<undef>.

=item $account_passwrod = '<password for the account>'

The mail account password. This is need B<ONLY> if your server type is a
SMTP_AUTH otherwise should be set to B<undef> (when server type is SMTP or SENDMAIL)

=item $debug_file = '<full path to a file for keeping copy of the entire mail taction>'

Full path to a file that will caputre the entire mail transaction. It is very usefull
when debugging the mail.

=item $debug = <1 or undef>

      1: debug mode
  undef: NO debug


=item Configuration table

B<X:>  Info is need

B<-:> set to B<undef>


             $from   $server_type   $athu_protocol  $server_name  $account_name   $account_passwrod

       SMTP    X         X                 -            X              X                 -

  SMTP_AUTH    X         X                 X            X              X                 X

    SNDMAIL    -         X                 -            -              -                 -

=back

=head2 Test your new mail configuration

B<check_mail.pl> is a simple perl program you can test the email configuration you
just finished it is lot easier to see it the setup is correct this program. Just
edit and replace the sender and recepient email addresses. and run the program

  perl  check_mail.pl


you shoud receive the email which will verify you configuration.


=head1 Author

Shahriar Mokhtarzad

contact_smt@pacbell.net

=cut

#:-)
